==> huaweicloudsdkvpc-3.1.134-py2.py3-none-any.whl: huaweicloudsdkvpc/v2/model/neutron_create_network_option.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NeutronCreateNetworkOption:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'admin_state_up': 'bool',
        'shared': 'bool',
        'providernetwork_type': 'str',
        'port_security_enabled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'admin_state_up': 'admin_state_up',
        'shared': 'shared',
        'providernetwork_type': 'provider:network_type',
        'port_security_enabled': 'port_security_enabled'
    }

    def __init__(self, name=None, admin_state_up=None, shared=None, providernetwork_type=None, port_security_enabled=None):
        """NeutronCreateNetworkOption

        The model defined in huaweicloud sdk

        :param name: 功能说明：网络名称 取值范围：0-255个字符 约束：不能为admin_external_net
        :type name: str
        :param admin_state_up: 功能说明：资源的管理状态 取值范围：true、false 约束：只支持true
        :type admin_state_up: bool
        :param shared: 功能说明：是否支持跨租户共享 取值范围：true、false
        :type shared: bool
        :param providernetwork_type: 功能说明：扩展属性：网络类型。管理员属性，普通租户不可见，允许 geneve类型租户执行操作。 取值范围：vxlan, geneve
        :type providernetwork_type: str
        :param port_security_enabled: 功能说明：端口安全使能标记 取值范围：true(启用)、false(禁用) 约束：如果不使能，则network下所有虚机的安全组和dhcp防欺骗不生效
        :type port_security_enabled: bool
        """
        
        

        self._name = None
        self._admin_state_up = None
        self._shared = None
        self._providernetwork_type = None
        self._port_security_enabled = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if admin_state_up is not None:
            self.admin_state_up = admin_state_up
        if shared is not None:
            self.shared = shared
        if providernetwork_type is not None:
            self.providernetwork_type = providernetwork_type
        if port_security_enabled is not None:
            self.port_security_enabled = port_security_enabled

    @property
    def name(self):
        """Gets the name of this NeutronCreateNetworkOption.

        功能说明：网络名称 取值范围：0-255个字符 约束：不能为admin_external_net

        :return: The name of this NeutronCreateNetworkOption.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NeutronCreateNetworkOption.

        功能说明：网络名称 取值范围：0-255个字符 约束：不能为admin_external_net

        :param name: The name of this NeutronCreateNetworkOption.
        :type name: str
        """
        self._name = name

    @property
    def admin_state_up(self):
        """Gets the admin_state_up of this NeutronCreateNetworkOption.

        功能说明：资源的管理状态 取值范围：true、false 约束：只支持true

        :return: The admin_state_up of this NeutronCreateNetworkOption.
        :rtype: bool
        """
        return self._admin_state_up

    @admin_state_up.setter
    def admin_state_up(self, admin_state_up):
        """Sets the admin_state_up of this NeutronCreateNetworkOption.

        功能说明：资源的管理状态 取值范围：true、false 约束：只支持true

        :param admin_state_up: The admin_state_up of this NeutronCreateNetworkOption.
        :type admin_state_up: bool
        """
        self._admin_state_up = admin_state_up

    @property
    def shared(self):
        """Gets the shared of this NeutronCreateNetworkOption.

        功能说明：是否支持跨租户共享 取值范围：true、false

        :return: The shared of this NeutronCreateNetworkOption.
        :rtype: bool
        """
        return self._shared

    @shared.setter
    def shared(self, shared):
        """Sets the shared of this NeutronCreateNetworkOption.

        功能说明：是否支持跨租户共享 取值范围：true、false

        :param shared: The shared of this NeutronCreateNetworkOption.
        :type shared: bool
        """
        self._shared = shared

    @property
    def providernetwork_type(self):
        """Gets the providernetwork_type of this NeutronCreateNetworkOption.

        功能说明：扩展属性：网络类型。管理员属性，普通租户不可见，允许 geneve类型租户执行操作。 取值范围：vxlan, geneve

        :return: The providernetwork_type of this NeutronCreateNetworkOption.
        :rtype: str
        """
        return self._providernetwork_type

    @providernetwork_type.setter
    def providernetwork_type(self, providernetwork_type):
        """Sets the providernetwork_type of this NeutronCreateNetworkOption.

        功能说明：扩展属性：网络类型。管理员属性，普通租户不可见，允许 geneve类型租户执行操作。 取值范围：vxlan, geneve

        :param providernetwork_type: The providernetwork_type of this NeutronCreateNetworkOption.
        :type providernetwork_type: str
        """
        self._providernetwork_type = providernetwork_type

    @property
    def port_security_enabled(self):
        """Gets the port_security_enabled of this NeutronCreateNetworkOption.

        功能说明：端口安全使能标记 取值范围：true(启用)、false(禁用) 约束：如果不使能，则network下所有虚机的安全组和dhcp防欺骗不生效

        :return: The port_security_enabled of this NeutronCreateNetworkOption.
        :rtype: bool
        """
        return self._port_security_enabled

    @port_security_enabled.setter
    def port_security_enabled(self, port_security_enabled):
        """Sets the port_security_enabled of this NeutronCreateNetworkOption.

        功能说明：端口安全使能标记 取值范围：true(启用)、false(禁用) 约束：如果不使能，则network下所有虚机的安全组和dhcp防欺骗不生效

        :param port_security_enabled: The port_security_enabled of this NeutronCreateNetworkOption.
        :type port_security_enabled: bool
        """
        self._port_security_enabled = port_security_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NeutronCreateNetworkOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v2/model/neutron_create_network_option.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NeutronCreateNetworkOption:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'admin_state_up': 'bool',
        'shared': 'bool',
        'providernetwork_type': 'str',
        'port_security_enabled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'admin_state_up': 'admin_state_up',
        'shared': 'shared',
        'providernetwork_type': 'provider:network_type',
        'port_security_enabled': 'port_security_enabled'
    }

    def __init__(self, name=None, admin_state_up=None, shared=None, providernetwork_type=None, port_security_enabled=None):
        r"""NeutronCreateNetworkOption

        The model defined in huaweicloud sdk

        :param name: 功能说明：网络名称 取值范围：0-255个字符 约束：不能为admin_external_net
        :type name: str
        :param admin_state_up: 功能说明：资源的管理状态 取值范围：true、false 约束：只支持true
        :type admin_state_up: bool
        :param shared: 功能说明：是否支持跨租户共享 取值范围：true、false
        :type shared: bool
        :param providernetwork_type: 功能说明：扩展属性：网络类型。管理员属性，普通租户不可见，允许 geneve类型租户执行操作。 取值范围：vxlan, geneve
        :type providernetwork_type: str
        :param port_security_enabled: 功能说明：端口安全使能标记 取值范围：true(启用)、false(禁用) 约束：如果不使能，则network下所有虚机的安全组和dhcp防欺骗不生效
        :type port_security_enabled: bool
        """
        
        

        self._name = None
        self._admin_state_up = None
        self._shared = None
        self._providernetwork_type = None
        self._port_security_enabled = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if admin_state_up is not None:
            self.admin_state_up = admin_state_up
        if shared is not None:
            self.shared = shared
        if providernetwork_type is not None:
            self.providernetwork_type = providernetwork_type
        if port_security_enabled is not None:
            self.port_security_enabled = port_security_enabled

    @property
    def name(self):
        r"""Gets the name of this NeutronCreateNetworkOption.

        功能说明：网络名称 取值范围：0-255个字符 约束：不能为admin_external_net

        :return: The name of this NeutronCreateNetworkOption.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this NeutronCreateNetworkOption.

        功能说明：网络名称 取值范围：0-255个字符 约束：不能为admin_external_net

        :param name: The name of this NeutronCreateNetworkOption.
        :type name: str
        """
        self._name = name

    @property
    def admin_state_up(self):
        r"""Gets the admin_state_up of this NeutronCreateNetworkOption.

        功能说明：资源的管理状态 取值范围：true、false 约束：只支持true

        :return: The admin_state_up of this NeutronCreateNetworkOption.
        :rtype: bool
        """
        return self._admin_state_up

    @admin_state_up.setter
    def admin_state_up(self, admin_state_up):
        r"""Sets the admin_state_up of this NeutronCreateNetworkOption.

        功能说明：资源的管理状态 取值范围：true、false 约束：只支持true

        :param admin_state_up: The admin_state_up of this NeutronCreateNetworkOption.
        :type admin_state_up: bool
        """
        self._admin_state_up = admin_state_up

    @property
    def shared(self):
        r"""Gets the shared of this NeutronCreateNetworkOption.

        功能说明：是否支持跨租户共享 取值范围：true、false

        :return: The shared of this NeutronCreateNetworkOption.
        :rtype: bool
        """
        return self._shared

    @shared.setter
    def shared(self, shared):
        r"""Sets the shared of this NeutronCreateNetworkOption.

        功能说明：是否支持跨租户共享 取值范围：true、false

        :param shared: The shared of this NeutronCreateNetworkOption.
        :type shared: bool
        """
        self._shared = shared

    @property
    def providernetwork_type(self):
        r"""Gets the providernetwork_type of this NeutronCreateNetworkOption.

        功能说明：扩展属性：网络类型。管理员属性，普通租户不可见，允许 geneve类型租户执行操作。 取值范围：vxlan, geneve

        :return: The providernetwork_type of this NeutronCreateNetworkOption.
        :rtype: str
        """
        return self._providernetwork_type

    @providernetwork_type.setter
    def providernetwork_type(self, providernetwork_type):
        r"""Sets the providernetwork_type of this NeutronCreateNetworkOption.

        功能说明：扩展属性：网络类型。管理员属性，普通租户不可见，允许 geneve类型租户执行操作。 取值范围：vxlan, geneve

        :param providernetwork_type: The providernetwork_type of this NeutronCreateNetworkOption.
        :type providernetwork_type: str
        """
        self._providernetwork_type = providernetwork_type

    @property
    def port_security_enabled(self):
        r"""Gets the port_security_enabled of this NeutronCreateNetworkOption.

        功能说明：端口安全使能标记 取值范围：true(启用)、false(禁用) 约束：如果不使能，则network下所有虚机的安全组和dhcp防欺骗不生效

        :return: The port_security_enabled of this NeutronCreateNetworkOption.
        :rtype: bool
        """
        return self._port_security_enabled

    @port_security_enabled.setter
    def port_security_enabled(self, port_security_enabled):
        r"""Sets the port_security_enabled of this NeutronCreateNetworkOption.

        功能说明：端口安全使能标记 取值范围：true(启用)、false(禁用) 约束：如果不使能，则network下所有虚机的安全组和dhcp防欺骗不生效

        :param port_security_enabled: The port_security_enabled of this NeutronCreateNetworkOption.
        :type port_security_enabled: bool
        """
        self._port_security_enabled = port_security_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NeutronCreateNetworkOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
